---
layout: page
title: Common Ground Workshop Design and Facilitation Toolkit
permalink: /toolkit/
---

This guide is meant to provide a resource to anyone interested in running their own "Finding Common Ground" workshop. The toolkit is licensed under a Creative Commons CC-BY-whatever license. Have an idea or suggestion on how this might be changed or improved? Please feel free to create an issue or push request on github! Any and all contributions are welcome.

# Step 1. Decide what you want to (aspire to) achieve

There are basically two kinds of workshop that you can facilitate: a big "firehose" group (say, 40-80 participants) which draws in as big a crowd as possible or a small and more focussed group which can taken on an intimate setting and a highly focussed geographical area. As we'll note later, there are different ways of facilitating these two formats.

# Step 2. Find your collaborators

The finding common ground project was predicated on the idea that there are existing grassroots efforts likely already underway in your local community. Another way of putting this is that, in contrast to the many guides to community mobilisation which assume that you are starting with a blank slate, we are mobilising a strengths-based approach here, so this process begins with reconaissance. You may want to have a look at our companion project, [Mapping Community](http://mapping.community) where we are engaged in an ongoing and collaborative effort to provide the most comprehensive and accurate birds-eye view of community groups using a healthy mix of grassroots, big data, and digital cartography. However, it is important to emphasise that this data should be used with care. There is simply no substitute for on-the-ground local knowledge when it comes to facilitating this kind of gathering. So in the early stages, you'll want to both cultivate a "long list" of groups to invite participation from and pursue specific collaborative partners, ideally one or two co-hosts who have a long involvement or patronage of local groups. Your co-hosts can help you to navigate possible sheduling conflicts that might arise locally, curate a list of contacts, find new groups that aren't on the map, and help to break the ice when it comes time to run your workshop. I can't emphasise how important it is to have someone involved in the workshop that has already been working in some local context, ideally for at least 5 years.

Keep an open mind about the scale of your effort. After an initial look you may realise that the area you had in mind is far too wide or narrow. Assume that half of the groups you approach will not be able to participate and that another 25% may show up without any invitation.


# Step 3. Draw a Crowd

## Scheduling and Venue

At least 3-6 months out, you should set a date, time, and venue for your workshop. If you foresee potential conflicts, you can schedule two events in close proximity and then join them together with good design (more on this later). Consult with your local hosts and float some possible dates and test the waters. Remember that many participants may have day-jobs, school, or children, so Saturday or Sunday afternoon is probably your best bet.

Confer with your co-hosts on some good venues as well. A good venue should have natural light, tables to sit around that will facilitate conversation, and enough room for people to mill around when it comes time for activities. Since we're trying to find common ground here, be careful also to find a venue that doesn't support one specific group over others. Conversely, you may be able to support a local community centre, social hub, or church hall. Consider also whether you want to make the event multi-generational and to what degree, and make sure there is space to accomodate this design choice. If there will be small children, you'll want to have space for them to be noisy and active. Also be sure to consider how you can ensure accessibility to your venue for persons with disabilities. Can you avoid extra stairs? Is there a PA system with a hearing loop for persons who are hearing impaired? Float possible dates with your preferred venue, and be prepared to be flexible.

Create an online registration page for your event. Make sure you ask for them to let you know how they'd like to be contacted as you continue to plan the event (and factor this in to your work below). Eventbrite offers a free service that scales pretty well to these workshops.

## Invitations

Now that you have a date and venue chosen, you'll need to begin the process of drawing in your crowd. It's fine to start with email. I recommend that you compose 2-3 templates that you can tailor so that each participant gets an email designed for them which addresses them by name and acknowledges the work of their group. Provide basic details for the event, and especially make clear why it is significant and why you've chosen this area in particular to host a workshop. I also recommend (as you'll see in the sample below) that you highlight the importance of inviting youth to participate as they may not be included by default and will help to add a level of dynamism and energy to the workshop which may prove to be vital to its success.

Here's a sample template you can modify and use for your invitations:

[sample here]

Build yourself a spreadsheet so you can keep track of who has been invited and whether they have responded. Here's a template you can paste into a google docs spreadsheet:

[sample here]

Find local media outlets where you can post open announcements to solicit participants for your workshop. Put together a print flyer that your local co-hosts can print a leave at coffee shops, community centres, local churches, etc.

After 1-2 weeks, follow-up with groups that haven't responded.

# Step 4. Lay the Groundwork

## Pre-event questionnaire

We've devised a pre-event questionnaire that you can send around to participants. This will serve three purposes: (1) to help you as the organiser to tailor the event to local concerns and dynamics before the day has even begun; (2) to represent voices and perspectives of persons who may not be able to participate or may not feel as comfortable representing themselves in a group setting; and (3) to track whether the workshop has any impact and what kind of shifts may occur in local thinking about resources and planning on issues of concern.

Here's a sample questionnaire you can send around:

[sample questionairre]

1. Basic logistics: name, gender, age, place of birth
2. How did you hear about the workshop?
3. What groups are you affiliated with?
3b. How and why did you first get involved in ____ ?
3c. How would you describe your group to a stranger? (2-3 sentences maximum)
4. Are there other groups in your area that are similar to yours? if so, who and how?
5. What are the key issues relating to sustainability and resilience on a local level in your community?
6. What resources exist to draw on in solving these issues? 
7. What are the major barriers to progress?
8. What is one area of concern you've identified under (5) above where you'd really like to make some progress in the next year?
9. How would you measure success or progress on this area of concern?

Be prepared to print and mail out questionnaires with a pre-addressed and postage paid return envelope for those persons who have specified that they'd prefer not to be contacted via email.

## Touch base

Run a conference call with your co-organisers to discuss the list of participants who have registered for your event, diagnose possible gaps where they exist. Now is also the time to confirm a possible catering option, ideally a local co-operative provider or some of the groups participating. You might consider hosting a shared meal if there is adequate interest and energy.

# Step 5. Design the Day

We run these finding common ground workshops in a participatory (or "unconference") style. It is a common mistake to think that less structured formats require less preparation, but this is a serious mistake. The less structure you'll have in place on the day of your event, the more important it is to make sure you've designed a format for the day that can be maximally inclusive, engaging, and well-paced for conversation and creativity.

Here's another reason that the format will be particularly crucial for your event: many if not most of the people you're drawing into these workshops are the unsung heroes of their communities. They've invested thousands of hours if not decades of their lives in trying to develop local solutions. The point of these workshops if to surmount this invisibility problem, but once we invite people to open up, they may have quite a lot to say and strong feelings about local legacies. We'll design the day to incorporate this energy, with "release valves" at strategic moments to give everyone a chance to speak their minds and blow off some steam. We'll also design a range of different channels through which persons can communicate about the things that are significant to them. Without proper planning, we may give a platform to people who speak loudly and close down those persons who do not usually speak. A counterproductive workshop deployed in this context may be worse than not running one at all. This is not to say that you can design a way around any possible disagreement or interpersonal tension, but that it can play a very important role that should not be underestimated.

How will you accomplish this? Let's explore some options and chart out the proper rhythm for the day.

## 1. Welcome

You'll begin with a welcome, but this doesn't start with talking, it starts with the way you arrange the space. Make sure there are drinks and a light snack. Coffee and tea are fine, but I like to include fruit juice and chilled water which can be a bit more refreshing. You're going to have a wide range of different personalities in the room, so prepare some different contexts in which people can feel welcome. Many will feel quite comfortable chatting up their friends over a cup of tea, but others who are introverts (like me!) might like to have something to facilitate an introduction or light conversation. Here are a few ideas for facilitations:

(1) Put up a big unlabelled map of your community on a board or table and invite persons to place themselves, their group, local problems, and local resources on the map.

(2) Put out A0 sized sheets of paper on several different tables and write an unfinished sentence at the top, like, "Our community is _______" or "In [place name] I'd like to see ________"

(3) Invite one or two people to help you arrange logistics, pass out drinks or snacks.

Once everyone has arrived and has had a chance to get settled in, formally open the session and invite everyone to take a seat. I recommend that you aquire some kind of musical instrument to indicate breaks in the session (including the opening).

Now begin the formal introduction. Explain why you've chosen to host the workshop, invite 1-2 persons who are your co-hosts to include their voices in this part. Emphasise how welcome everyone is, and then explain what the day's events will include. Set expectations, in particular note how important it is that everyone has a chance to have a voice in the conversation and that the day will include a wide range of styles and experiences. Everyone should expect to be out of their "comfort zone" for some part of the day. Provide participants with a map for the whole session so they know what to expect, then lead into the next "moment":

## 2. Introductions

## 3. Problems

## 4. Solutions

## 5. Collaborations



# Step 6. Assemble supplies



# Step 7. Run your workshop!




